import { Unsubscribable } from 'rxjs';
import * as cdeops from 'cdeops/client';
import { ICommandHandlerDescription, IConfigurationOverrides } from '@workbench-stack/core';
import { IConfigurationChange } from '@adminide-stack/core';
import { ConfigurationTarget } from 'common';
import { ITextDocumentItem } from '@workbench-stack/core';
import { UriComponents } from '@vscode-alt/monaco-editor/esm/vs/base/common/uri';
import { IRPCProtocol, ProxyIdentifier } from './proxy-identifier';
import { IOrganizationData, ILanguageFeaturesShape, IConfigurationInitData } from './common.protocol';
import { IModelChangedEvent } from './temporary-types';
/**
 * Required information when initializing an extension host.
 */
export interface IClientInitData {
    organization?: IOrganizationData | null;
    /** @see {@link module: cdeops.internal.cdeopsURL} */
    cdeopsURL: string;
    /** @see {@link module: cdeops.internal.clientAPplication} */
    clientApplication: 'cdeops' | 'other';
    graphqlSubscriptionUrl?: string;
    extensionSocketUrl?: string;
}
export interface IWebExtHostContext extends IRPCProtocol {
}
export interface IClientContext extends IRPCProtocol {
}
export interface WebExtHostExtensionServiceShape {
    $activateExtension(extensionID: string, bundleURL: string): Promise<void>;
    $deactivateExtension(extensionID: string): Promise<void>;
}
export interface ClientThreadConfigurationShape {
    $updateConfigurationOption(target: ConfigurationTarget, key: string, value: any, overrides: IConfigurationOverrides): Promise<void>;
    $removeConfigurationOption(target: ConfigurationTarget, key: string, overrides: IConfigurationOverrides): Promise<void>;
}
export interface ClientThreadConfigurationRoleShape {
    $updateConfigurationOption(target: ConfigurationTarget, key: string, value: any, overrides: IConfigurationOverrides): Promise<void>;
    $removeConfigurationOption(target: ConfigurationTarget, key: string, overrides: IConfigurationOverrides): Promise<void>;
}
export interface ClientThreadConfigurationPolicyShape {
    $updateConfigurationOption(target: ConfigurationTarget, key: string, value: any, roverrides: IConfigurationOverrides): Promise<void>;
    $removeConfigurationOption(target: ConfigurationTarget, key: string, overrides: IConfigurationOverrides): Promise<void>;
}
export interface WebExtHostConfigurationShape {
    $initializeConfiguration(data: IConfigurationInitData): void;
    $acceptConfigurationChanged(data: IConfigurationInitData, change: IConfigurationChange): void;
}
export interface WebExtHostConfigurationRoleShape {
    $initializeConfiguration(data: IConfigurationInitData): void;
    $acceptConfigurationChanged(data: IConfigurationInitData, change: IConfigurationChange): void;
}
export interface WebExtHostConfigurationPolicyShape {
    $initializeConfiguration(data: IConfigurationInitData): void;
    $acceptConfigurationChanged(data: IConfigurationInitData, change: IConfigurationChange): void;
}
export interface WebExtHostOrganizationShape {
    $acceptOrganizationData(organization: IOrganizationData): void;
}
export interface ClientThreadOrganizationShape {
    $checkExists(includes: string[]): Promise<boolean>;
    $saveAll(includeUntitled?: boolean): Promise<boolean>;
    $updateOrganizationResources(extensionName: string, index: number, deleteCount: number, organizationResourcesToAdd: {
        uri: UriComponents;
        name?: string;
    }[]): Promise<void>;
    $resolveProxy(url: string): Promise<string>;
}
export interface ClientThreadLanguageFeaturesShape extends ILanguageFeaturesShape {
}
export interface WebExtHostDocumentsShape {
    $acceptDocumentData(doc: ITextDocumentItem[]): void;
    $acceptModelChanged(strURL: UriComponents, e: IModelChangedEvent, isDirty: boolean): void;
}
export interface ClientThreadCommandsShape extends Unsubscribable {
    $unregister(id: number): void;
    $registerCommand(id: number, command: string): void;
    $executeCommand<T>(command: string, args: any[]): Promise<any>;
}
export interface WebExtHostCommandShape {
    $executeContributedCommand<T>(id: number, args: any[]): Promise<any>;
    $getContributedCommandHandlerDescriptions(): Promise<{
        [id: string]: string | ICommandHandlerDescription;
    }>;
}
/** @internal */
export interface PanelViewData extends Pick<cdeops.PanelView, 'title' | 'content' | 'priority' | 'component'> {
}
/** @internal */
export interface ClientThreadViewsShape {
    $unregister(id: number): void;
    $registerPanelViewProvider(id: number, provider: {
        id: string;
    }): void;
    $acceptPanelViewUpdate(id: number, params: Partial<PanelViewData>): void;
}
export interface ClientThreadContextShape {
    $acceptContextUpdates(updates: cdeops.ContextValues): void;
}
export declare const ClientContext: {
    ClientThreadLanguageFeatures: ProxyIdentifier<ClientThreadLanguageFeaturesShape>;
};
